@@ -3,10 +3,12 @@ from decimal import Decimal
 
 NUMBER_TYPES = (int, float, Decimal)
 
-__version__ = "0.1.2"
-__version_info__ = (0, 1, 2)
+__version__ = "0.1.10"
+__name__ = "calculation-mapilio"
+__major__ = False
+__minor__ = False
+__patch__ = True
+
 
 logger = logging.getLogger('calculation')
 
-def get_version():
-    return __version__
